@@ -22,10 +22,10 @@ from opentelemetry._logs import get_logger as APIGetLogger
 from opentelemetry.attributes import BoundedAttributes
 from opentelemetry.sdk import trace
 from opentelemetry.sdk._logs import (
-    LogData,
     LoggerProvider,
     LoggingHandler,
     LogRecordProcessor,
+    ReadableLogRecord,
 )
 from opentelemetry.sdk.environment_variables import OTEL_ATTRIBUTE_COUNT_LIMIT
 from opentelemetry.semconv._incubating.attributes import code_attributes
@@ -101,13 +101,18 @@ class TestLoggingHandler(unittest.TestCase):
         with self.assertLogs(level=logging.WARNING):
             logger.warning("Warning message")
 
-        log_record = processor.get_log_record(0)
+        record = processor.get_log_record(0)
 
-        self.assertIsNotNone(log_record)
-        self.assertEqual(log_record.trace_id, INVALID_SPAN_CONTEXT.trace_id)
-        self.assertEqual(log_record.span_id, INVALID_SPAN_CONTEXT.span_id)
+        self.assertIsNotNone(record)
         self.assertEqual(
-            log_record.trace_flags, INVALID_SPAN_CONTEXT.trace_flags
+            record.log_record.trace_id, INVALID_SPAN_CONTEXT.trace_id
+        )
+        self.assertEqual(
+            record.log_record.span_id, INVALID_SPAN_CONTEXT.span_id
+        )
+        self.assertEqual(
+            record.log_record.trace_flags,
+            INVALID_SPAN_CONTEXT.trace_flags,
         )
 
     def test_log_record_observed_timestamp(self):
@@ -116,37 +121,39 @@ class TestLoggingHandler(unittest.TestCase):
         with self.assertLogs(level=logging.WARNING):
             logger.warning("Warning message")
 
-        log_record = processor.get_log_record(0)
-        self.assertIsNotNone(log_record.observed_timestamp)
+        record = processor.get_log_record(0)
+        self.assertIsNotNone(record.log_record.observed_timestamp)
 
     def test_log_record_user_attributes(self):
-        """Attributes can be injected into logs by adding them to the LogRecord"""
+        """Attributes can be injected into logs by adding them to the ReadWriteLogRecord"""
         processor, logger = set_up_test_logging(logging.WARNING)
 
         # Assert emit gets called for warning message
         with self.assertLogs(level=logging.WARNING):
             logger.warning("Warning message", extra={"http.status_code": 200})
 
-        log_record = processor.get_log_record(0)
+        record = processor.get_log_record(0)
 
-        self.assertIsNotNone(log_record)
-        self.assertEqual(len(log_record.attributes), 4)
-        self.assertEqual(log_record.attributes["http.status_code"], 200)
+        self.assertIsNotNone(record)
+        self.assertEqual(len(record.log_record.attributes), 4)
+        self.assertEqual(record.log_record.attributes["http.status_code"], 200)
         self.assertTrue(
-            log_record.attributes[code_attributes.CODE_FILE_PATH].endswith(
-                "test_handler.py"
-            )
+            record.log_record.attributes[
+                code_attributes.CODE_FILE_PATH
+            ].endswith("test_handler.py")
         )
         self.assertEqual(
-            log_record.attributes[code_attributes.CODE_FUNCTION_NAME],
+            record.log_record.attributes[code_attributes.CODE_FUNCTION_NAME],
             "test_log_record_user_attributes",
         )
         # The line of the log statement is not a constant (changing tests may change that),
         # so only check that the attribute is present.
         self.assertTrue(
-            code_attributes.CODE_LINE_NUMBER in log_record.attributes
+            code_attributes.CODE_LINE_NUMBER in record.log_record.attributes
+        )
+        self.assertTrue(
+            isinstance(record.log_record.attributes, BoundedAttributes)
         )
-        self.assertTrue(isinstance(log_record.attributes, BoundedAttributes))
 
     def test_log_record_exception(self):
         """Exception information will be included in attributes"""
@@ -158,20 +165,22 @@ class TestLoggingHandler(unittest.TestCase):
             with self.assertLogs(level=logging.ERROR):
                 logger.exception("Zero Division Error")
 
-        log_record = processor.get_log_record(0)
+        record = processor.get_log_record(0)
 
-        self.assertIsNotNone(log_record)
-        self.assertTrue(isinstance(log_record.body, str))
-        self.assertEqual(log_record.body, "Zero Division Error")
+        self.assertIsNotNone(record)
+        self.assertTrue(isinstance(record.log_record.body, str))
+        self.assertEqual(record.log_record.body, "Zero Division Error")
         self.assertEqual(
-            log_record.attributes[exception_attributes.EXCEPTION_TYPE],
+            record.log_record.attributes[exception_attributes.EXCEPTION_TYPE],
             ZeroDivisionError.__name__,
         )
         self.assertEqual(
-            log_record.attributes[exception_attributes.EXCEPTION_MESSAGE],
+            record.log_record.attributes[
+                exception_attributes.EXCEPTION_MESSAGE
+            ],
             "division by zero",
         )
-        stack_trace = log_record.attributes[
+        stack_trace = record.log_record.attributes[
             exception_attributes.EXCEPTION_STACKTRACE
         ]
         self.assertIsInstance(stack_trace, str)
@@ -192,19 +201,21 @@ class TestLoggingHandler(unittest.TestCase):
             with self.assertLogs(level=logging.ERROR):
                 logger.exception("Zero Division Error")
 
-        log_record = processor.get_log_record(0)
+        record = processor.get_log_record(0)
 
-        self.assertIsNotNone(log_record)
-        self.assertEqual(log_record.body, "Zero Division Error")
+        self.assertIsNotNone(record)
+        self.assertEqual(record.log_record.body, "Zero Division Error")
         self.assertEqual(
-            log_record.attributes[exception_attributes.EXCEPTION_TYPE],
+            record.log_record.attributes[exception_attributes.EXCEPTION_TYPE],
             ZeroDivisionError.__name__,
         )
         self.assertEqual(
-            log_record.attributes[exception_attributes.EXCEPTION_MESSAGE],
+            record.log_record.attributes[
+                exception_attributes.EXCEPTION_MESSAGE
+            ],
             "division by zero",
         )
-        stack_trace = log_record.attributes[
+        stack_trace = record.log_record.attributes[
             exception_attributes.EXCEPTION_STACKTRACE
         ]
         self.assertIsInstance(stack_trace, str)
@@ -223,18 +234,21 @@ class TestLoggingHandler(unittest.TestCase):
             with self.assertLogs(level=logging.ERROR):
                 logger.error("Zero Division Error", exc_info=False)
 
-        log_record = processor.get_log_record(0)
+        record = processor.get_log_record(0)
 
-        self.assertIsNotNone(log_record)
-        self.assertEqual(log_record.body, "Zero Division Error")
+        self.assertIsNotNone(record)
+        self.assertEqual(record.log_record.body, "Zero Division Error")
         self.assertNotIn(
-            exception_attributes.EXCEPTION_TYPE, log_record.attributes
+            exception_attributes.EXCEPTION_TYPE,
+            record.log_record.attributes,
         )
         self.assertNotIn(
-            exception_attributes.EXCEPTION_MESSAGE, log_record.attributes
+            exception_attributes.EXCEPTION_MESSAGE,
+            record.log_record.attributes,
         )
         self.assertNotIn(
-            exception_attributes.EXCEPTION_STACKTRACE, log_record.attributes
+            exception_attributes.EXCEPTION_STACKTRACE,
+            record.log_record.attributes,
         )
 
     def test_log_record_exception_with_object_payload(self):
@@ -250,20 +264,22 @@ class TestLoggingHandler(unittest.TestCase):
             with self.assertLogs(level=logging.ERROR):
                 logger.exception(exception)
 
-        log_record = processor.get_log_record(0)
+        record = processor.get_log_record(0)
 
-        self.assertIsNotNone(log_record)
-        self.assertTrue(isinstance(log_record.body, str))
-        self.assertEqual(log_record.body, "CustomException stringified")
+        self.assertIsNotNone(record)
+        self.assertTrue(isinstance(record.log_record.body, str))
+        self.assertEqual(record.log_record.body, "CustomException stringified")
         self.assertEqual(
-            log_record.attributes[exception_attributes.EXCEPTION_TYPE],
+            record.log_record.attributes[exception_attributes.EXCEPTION_TYPE],
             CustomException.__name__,
         )
         self.assertEqual(
-            log_record.attributes[exception_attributes.EXCEPTION_MESSAGE],
+            record.log_record.attributes[
+                exception_attributes.EXCEPTION_MESSAGE
+            ],
             "CustomException message",
         )
-        stack_trace = log_record.attributes[
+        stack_trace = record.log_record.attributes[
             exception_attributes.EXCEPTION_STACKTRACE
         ]
         self.assertIsInstance(stack_trace, str)
@@ -285,21 +301,28 @@ class TestLoggingHandler(unittest.TestCase):
                 with self.assertLogs(level=logging.CRITICAL):
                     logger.critical("Critical message within span")
 
-                log_record = processor.get_log_record(0)
+                record = processor.get_log_record(0)
 
                 self.assertEqual(
-                    log_record.body, "Critical message within span"
+                    record.log_record.body,
+                    "Critical message within span",
                 )
-                self.assertEqual(log_record.severity_text, "CRITICAL")
+                self.assertEqual(record.log_record.severity_text, "CRITICAL")
                 self.assertEqual(
-                    log_record.severity_number, SeverityNumber.FATAL
+                    record.log_record.severity_number,
+                    SeverityNumber.FATAL,
                 )
-                self.assertEqual(log_record.context, mock_context)
+                self.assertEqual(record.log_record.context, mock_context)
                 span_context = span.get_span_context()
-                self.assertEqual(log_record.trace_id, span_context.trace_id)
-                self.assertEqual(log_record.span_id, span_context.span_id)
                 self.assertEqual(
-                    log_record.trace_flags, span_context.trace_flags
+                    record.log_record.trace_id, span_context.trace_id
+                )
+                self.assertEqual(
+                    record.log_record.span_id, span_context.span_id
+                )
+                self.assertEqual(
+                    record.log_record.trace_flags,
+                    span_context.trace_flags,
                 )
 
     def test_log_record_trace_correlation_deprecated(self):
@@ -310,29 +333,35 @@ class TestLoggingHandler(unittest.TestCase):
             with self.assertLogs(level=logging.CRITICAL):
                 logger.critical("Critical message within span")
 
-            log_record = processor.get_log_record(0)
+            record = processor.get_log_record(0)
 
-            self.assertEqual(log_record.body, "Critical message within span")
-            self.assertEqual(log_record.severity_text, "CRITICAL")
-            self.assertEqual(log_record.severity_number, SeverityNumber.FATAL)
+            self.assertEqual(
+                record.log_record.body, "Critical message within span"
+            )
+            self.assertEqual(record.log_record.severity_text, "CRITICAL")
+            self.assertEqual(
+                record.log_record.severity_number, SeverityNumber.FATAL
+            )
             span_context = span.get_span_context()
-            self.assertEqual(log_record.trace_id, span_context.trace_id)
-            self.assertEqual(log_record.span_id, span_context.span_id)
-            self.assertEqual(log_record.trace_flags, span_context.trace_flags)
+            self.assertEqual(record.log_record.trace_id, span_context.trace_id)
+            self.assertEqual(record.log_record.span_id, span_context.span_id)
+            self.assertEqual(
+                record.log_record.trace_flags, span_context.trace_flags
+            )
 
     def test_warning_without_formatter(self):
         processor, logger = set_up_test_logging(logging.WARNING)
         logger.warning("Test message")
 
-        log_record = processor.get_log_record(0)
-        self.assertEqual(log_record.body, "Test message")
+        record = processor.get_log_record(0)
+        self.assertEqual(record.log_record.body, "Test message")
 
     def test_exception_without_formatter(self):
         processor, logger = set_up_test_logging(logging.WARNING)
         logger.exception("Test exception")
 
-        log_record = processor.get_log_record(0)
-        self.assertEqual(log_record.body, "Test exception")
+        record = processor.get_log_record(0)
+        self.assertEqual(record.log_record.body, "Test exception")
 
     def test_warning_with_formatter(self):
         processor, logger = set_up_test_logging(
@@ -343,8 +372,10 @@ class TestLoggingHandler(unittest.TestCase):
         )
         logger.warning("Test message")
 
-        log_record = processor.get_log_record(0)
-        self.assertEqual(log_record.body, "foo - WARNING - Test message")
+        record = processor.get_log_record(0)
+        self.assertEqual(
+            record.log_record.body, "foo - WARNING - Test message"
+        )
 
     def test_log_body_is_always_string_with_formatter(self):
         processor, logger = set_up_test_logging(
@@ -355,8 +386,8 @@ class TestLoggingHandler(unittest.TestCase):
         )
         logger.warning(["something", "of", "note"])
 
-        log_record = processor.get_log_record(0)
-        self.assertIsInstance(log_record.body, str)
+        record = processor.get_log_record(0)
+        self.assertIsInstance(record.log_record.body, str)
 
     @patch.dict(os.environ, {"OTEL_SDK_DISABLED": "true"})
     def test_handler_root_logger_with_disabled_sdk_does_not_go_into_recursion_error(
@@ -373,7 +404,7 @@ class TestLoggingHandler(unittest.TestCase):
     def test_otel_attribute_count_limit_respected_in_logging_handler(self):
         """Test that OTEL_ATTRIBUTE_COUNT_LIMIT is properly respected by LoggingHandler."""
         # Create a new LoggerProvider within the patched environment
-        # This will create LogLimits() that reads from the environment variable
+        # This will create LogRecordLimits() that reads from the environment variable
         logger_provider = LoggerProvider()
         processor = FakeProcessor()
         logger_provider.add_log_record_processor(processor)
@@ -391,10 +422,10 @@ class TestLoggingHandler(unittest.TestCase):
                 "Test message with many attributes", extra=extra_attrs
             )
 
-        log_record = processor.get_log_record(0)
+        record = processor.get_log_record(0)
 
         # With OTEL_ATTRIBUTE_COUNT_LIMIT=3, should have exactly 3 attributes
-        total_attrs = len(log_record.attributes)
+        total_attrs = len(record.log_record.attributes)
         self.assertEqual(
             total_attrs,
             3,
@@ -403,16 +434,16 @@ class TestLoggingHandler(unittest.TestCase):
 
         # Should have 10 dropped attributes (10 custom + 3 code - 3 kept = 10 dropped)
         self.assertEqual(
-            log_record.dropped_attributes,
+            record.dropped_attributes,
             10,
-            f"Should have 10 dropped attributes, got {log_record.dropped_attributes}",
+            f"Should have 10 dropped attributes, got {record.dropped_attributes}",
         )
 
     @patch.dict(os.environ, {OTEL_ATTRIBUTE_COUNT_LIMIT: "5"})
     def test_otel_attribute_count_limit_includes_code_attributes(self):
         """Test that OTEL_ATTRIBUTE_COUNT_LIMIT applies to all attributes including code attributes."""
         # Create a new LoggerProvider within the patched environment
-        # This will create LogLimits() that reads from the environment variable
+        # This will create LogRecordLimits() that reads from the environment variable
         logger_provider = LoggerProvider()
         processor = FakeProcessor()
         logger_provider.add_log_record_processor(processor)
@@ -428,10 +459,10 @@ class TestLoggingHandler(unittest.TestCase):
         with self.assertLogs(level=logging.WARNING):
             logger.warning("Test message", extra=extra_attrs)
 
-        log_record = processor.get_log_record(0)
+        record = processor.get_log_record(0)
 
         # With OTEL_ATTRIBUTE_COUNT_LIMIT=5, should have exactly 5 attributes
-        total_attrs = len(log_record.attributes)
+        total_attrs = len(record.log_record.attributes)
         self.assertEqual(
             total_attrs,
             5,
@@ -440,9 +471,9 @@ class TestLoggingHandler(unittest.TestCase):
 
         # Should have 6 dropped attributes (8 user + 3 code - 5 kept = 6 dropped)
         self.assertEqual(
-            log_record.dropped_attributes,
+            record.dropped_attributes,
             6,
-            f"Should have 6 dropped attributes, got {log_record.dropped_attributes}",
+            f"Should have 6 dropped attributes, got {record.dropped_attributes}",
         )
 
     def test_logging_handler_without_env_var_uses_default_limit(self):
@@ -457,10 +488,10 @@ class TestLoggingHandler(unittest.TestCase):
                 "Test message with many attributes", extra=extra_attrs
             )
 
-        log_record = processor.get_log_record(0)
+        record = processor.get_log_record(0)
 
         # Should be limited to default limit (128) total attributes
-        total_attrs = len(log_record.attributes)
+        total_attrs = len(record.log_record.attributes)
         self.assertEqual(
             total_attrs,
             128,
@@ -469,9 +500,9 @@ class TestLoggingHandler(unittest.TestCase):
 
         # Should have 25 dropped attributes (150 user + 3 code - 128 kept = 25 dropped)
         self.assertEqual(
-            log_record.dropped_attributes,
+            record.dropped_attributes,
             25,
-            f"Should have 25 dropped attributes, got {log_record.dropped_attributes}",
+            f"Should have 25 dropped attributes, got {record.dropped_attributes}",
         )
 
 
@@ -491,8 +522,8 @@ class FakeProcessor(LogRecordProcessor):
     def __init__(self):
         self.log_data_emitted = []
 
-    def on_emit(self, log_data: LogData):
-        self.log_data_emitted.append(log_data)
+    def on_emit(self, log_record: ReadableLogRecord):
+        self.log_data_emitted.append(log_record)
 
     def shutdown(self):
         pass
@@ -504,4 +535,4 @@ class FakeProcessor(LogRecordProcessor):
         return len(self.log_data_emitted)
 
     def get_log_record(self, i):
-        return self.log_data_emitted[i].log_record
+        return self.log_data_emitted[i]
