@@ -46,8 +46,8 @@ from opentelemetry.sdk._configuration import (
     _OTelSDKConfigurator,
 )
 from opentelemetry.sdk._logs import LoggingHandler
-from opentelemetry.sdk._logs._internal.export import LogExporter
-from opentelemetry.sdk._logs.export import ConsoleLogExporter
+from opentelemetry.sdk._logs._internal.export import LogRecordExporter
+from opentelemetry.sdk._logs.export import ConsoleLogRecordExporter
 from opentelemetry.sdk.environment_variables import (
     OTEL_TRACES_SAMPLER,
     OTEL_TRACES_SAMPLER_ARG,
@@ -72,6 +72,7 @@ from opentelemetry.sdk.trace.sampling import (
     SamplingResult,
     TraceIdRatioBased,
 )
+from opentelemetry.test.mock_test_classes import IterEntryPoint
 from opentelemetry.trace import Link, SpanKind
 from opentelemetry.trace.span import TraceState
 from opentelemetry.util.types import Attributes
@@ -113,7 +114,19 @@ class DummyLogger:
         self.resource = resource
         self.processor = processor
 
-    def emit(self, record):
+    def emit(
+        self,
+        record=None,
+        *,
+        timestamp=None,
+        observed_timestamp=None,
+        context=None,
+        severity_number=None,
+        severity_text=None,
+        body=None,
+        attributes=None,
+        event_name=None,
+    ):
         self.processor.emit(record)
 
 
@@ -208,7 +221,7 @@ class OTLPSpanExporter:
         self.compression = compression
 
 
-class DummyOTLPLogExporter(LogExporter):
+class DummyOTLPLogExporter(LogRecordExporter):
     def __init__(self, compression: str | None = None, *args, **kwargs):
         self.export_called = False
         self.compression = compression
@@ -295,15 +308,6 @@ class CustomIdGenerator(IdGenerator):
         pass
 
 
-class IterEntryPoint:
-    def __init__(self, name, class_type):
-        self.name = name
-        self.class_type = class_type
-
-    def load(self):
-        return self.class_type
-
-
 class TestTraceInit(TestCase):
     def setUp(self):
         super()
@@ -1155,7 +1159,8 @@ class TestImportExporters(TestCase):
             trace_exporters["console"].__class__, ConsoleSpanExporter.__class__
         )
         self.assertEqual(
-            logs_exporters["console"].__class__, ConsoleLogExporter.__class__
+            logs_exporters["console"].__class__,
+            ConsoleLogRecordExporter.__class__,
         )
         self.assertEqual(
             metric_exporterts["console"].__class__,
